# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.wrapped_response_embeddings_response import WrappedResponseEmbeddingsResponse  # noqa: E501

class TestWrappedResponseEmbeddingsResponse(unittest.TestCase):
    """WrappedResponseEmbeddingsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseEmbeddingsResponse:
        """Test WrappedResponseEmbeddingsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseEmbeddingsResponse`
        """
        model = WrappedResponseEmbeddingsResponse()  # noqa: E501
        if include_optional:
            return WrappedResponseEmbeddingsResponse(
                done = True,
                result = openai_connector.models.embeddings_response.EmbeddingsResponse(
                    model = '', 
                    vectors = [
                        [
                            1.337
                            ]
                        ], 
                    input_tokens = 56, )
            )
        else:
            return WrappedResponseEmbeddingsResponse(
                result = openai_connector.models.embeddings_response.EmbeddingsResponse(
                    model = '', 
                    vectors = [
                        [
                            1.337
                            ]
                        ], 
                    input_tokens = 56, ),
        )
        """

    def testWrappedResponseEmbeddingsResponse(self):
        """Test WrappedResponseEmbeddingsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.chat_history_item import ChatHistoryItem  # noqa: E501

class TestChatHistoryItem(unittest.TestCase):
    """ChatHistoryItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatHistoryItem:
        """Test ChatHistoryItem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatHistoryItem`
        """
        model = ChatHistoryItem()  # noqa: E501
        if include_optional:
            return ChatHistoryItem(
                role = 'user',
                content = [
                    openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                        type = 'text', 
                        text = '', )
                    ]
            )
        else:
            return ChatHistoryItem(
                role = 'user',
                content = [
                    openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                        type = 'text', 
                        text = '', )
                    ],
        )
        """

    def testChatHistoryItem(self):
        """Test ChatHistoryItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.2.0+2611430737"

# Define package exports
__all__ = [
    "OpenaiApi",
    "OpenaiConnectorApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ChatHistoryChatContent",
    "ChatHistoryItem",
    "ChatRole",
    "EmbeddingsRequest",
    "EmbeddingsResponse",
    "FilePayload",
    "HTTPValidationError",
    "ImageResponse",
    "ImageSettings",
    "InputTokensDetails",
    "LocationInner",
    "OutputTokensDetails",
    "PromptBundle",
    "PromptBundleForGenerateImage",
    "ResponseChunk",
    "ResponseChunkType",
    "ResponseSchemaPayload",
    "ResponseUsage",
    "TextResponse",
    "Usage",
    "UsageDetails",
    "UsageInputTokensDetails",
    "ValidationError",
    "WrappedResponseEmbeddingsResponse",
    "WrappedResponseImageResponse",
    "WrappedResponseTextResponse",
]

# import apis into sdk package
from openai_connector.api.openai_api import OpenaiApi as OpenaiApi
from openai_connector.api.openai_connector_api import OpenaiConnectorApi as OpenaiConnectorApi

# import ApiClient
from openai_connector.api_response import ApiResponse as ApiResponse
from openai_connector.api_client import ApiClient as ApiClient
from openai_connector.configuration import Configuration as Configuration
from openai_connector.exceptions import OpenApiException as OpenApiException
from openai_connector.exceptions import ApiTypeError as ApiTypeError
from openai_connector.exceptions import ApiValueError as ApiValueError
from openai_connector.exceptions import ApiKeyError as ApiKeyError
from openai_connector.exceptions import ApiAttributeError as ApiAttributeError
from openai_connector.exceptions import ApiException as ApiException

# import models into sdk package
from openai_connector.models.chat_history_chat_content import ChatHistoryChatContent as ChatHistoryChatContent
from openai_connector.models.chat_history_item import ChatHistoryItem as ChatHistoryItem
from openai_connector.models.chat_role import ChatRole as ChatRole
from openai_connector.models.embeddings_request import EmbeddingsRequest as EmbeddingsRequest
from openai_connector.models.embeddings_response import EmbeddingsResponse as EmbeddingsResponse
from openai_connector.models.file_payload import FilePayload as FilePayload
from openai_connector.models.http_validation_error import HTTPValidationError as HTTPValidationError
from openai_connector.models.image_response import ImageResponse as ImageResponse
from openai_connector.models.image_settings import ImageSettings as ImageSettings
from openai_connector.models.input_tokens_details import InputTokensDetails as InputTokensDetails
from openai_connector.models.location_inner import LocationInner as LocationInner
from openai_connector.models.output_tokens_details import OutputTokensDetails as OutputTokensDetails
from openai_connector.models.prompt_bundle import PromptBundle as PromptBundle
from openai_connector.models.prompt_bundle_for_generate_image import PromptBundleForGenerateImage as PromptBundleForGenerateImage
from openai_connector.models.response_chunk import ResponseChunk as ResponseChunk
from openai_connector.models.response_chunk_type import ResponseChunkType as ResponseChunkType
from openai_connector.models.response_schema_payload import ResponseSchemaPayload as ResponseSchemaPayload
from openai_connector.models.response_usage import ResponseUsage as ResponseUsage
from openai_connector.models.text_response import TextResponse as TextResponse
from openai_connector.models.usage import Usage as Usage
from openai_connector.models.usage_details import UsageDetails as UsageDetails
from openai_connector.models.usage_input_tokens_details import UsageInputTokensDetails as UsageInputTokensDetails
from openai_connector.models.validation_error import ValidationError as ValidationError
from openai_connector.models.wrapped_response_embeddings_response import WrappedResponseEmbeddingsResponse as WrappedResponseEmbeddingsResponse
from openai_connector.models.wrapped_response_image_response import WrappedResponseImageResponse as WrappedResponseImageResponse
from openai_connector.models.wrapped_response_text_response import WrappedResponseTextResponse as WrappedResponseTextResponse



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from openai_connector.models.image_settings import ImageSettings

class PromptBundleForGenerateImage(BaseModel):
    """
    PromptBundleForGenerateImage
    """
    system_prompt: StrictStr = Field(...)
    user_prompt: StrictStr = Field(...)
    image_settings: ImageSettings = Field(...)
    skip_moderation: Optional[StrictBool] = False
    __properties = ["system_prompt", "user_prompt", "image_settings", "skip_moderation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PromptBundleForGenerateImage:
        """Create an instance of PromptBundleForGenerateImage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of image_settings
        if self.image_settings:
            _dict['image_settings'] = self.image_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PromptBundleForGenerateImage:
        """Create an instance of PromptBundleForGenerateImage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PromptBundleForGenerateImage.parse_obj(obj)

        _obj = PromptBundleForGenerateImage.parse_obj({
            "system_prompt": obj.get("system_prompt"),
            "user_prompt": obj.get("user_prompt"),
            "image_settings": ImageSettings.from_dict(obj.get("image_settings")) if obj.get("image_settings") is not None else None,
            "skip_moderation": obj.get("skip_moderation") if obj.get("skip_moderation") is not None else False
        })
        return _obj





# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.prompt_bundle_for_generate_image import PromptBundleForGenerateImage  # noqa: E501

class TestPromptBundleForGenerateImage(unittest.TestCase):
    """PromptBundleForGenerateImage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PromptBundleForGenerateImage:
        """Test PromptBundleForGenerateImage
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PromptBundleForGenerateImage`
        """
        model = PromptBundleForGenerateImage()  # noqa: E501
        if include_optional:
            return PromptBundleForGenerateImage(
                system_prompt = '',
                user_prompt = '',
                image_settings = openai_connector.models.image_settings.ImageSettings(
                    model = 'dall-e-2', 
                    count = 56, 
                    size = 'auto', 
                    quality = 'low', 
                    output_format = 'png', ),
                skip_moderation = True
            )
        else:
            return PromptBundleForGenerateImage(
                system_prompt = '',
                user_prompt = '',
                image_settings = openai_connector.models.image_settings.ImageSettings(
                    model = 'dall-e-2', 
                    count = 56, 
                    size = 'auto', 
                    quality = 'low', 
                    output_format = 'png', ),
        )
        """

    def testPromptBundleForGenerateImage(self):
        """Test PromptBundleForGenerateImage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from openai_connector.models.prompt_bundle import PromptBundle  # noqa: E501

class TestPromptBundle(unittest.TestCase):
    """PromptBundle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PromptBundle:
        """Test PromptBundle
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PromptBundle`
        """
        model = PromptBundle()  # noqa: E501
        if include_optional:
            return PromptBundle(
                model = '',
                system_prompt = '',
                history = [
                    openai_connector.models.chat_history_item.ChatHistoryItem(
                        role = 'user', 
                        content = [
                            openai_connector.models.chat_history_chat_content.ChatHistoryChatContent(
                                type = 'text', 
                                text = '', )
                            ], )
                    ],
                user_prompt = '',
                file = openai_connector.models.file_payload.FilePayload(
                    payload = '', 
                    prompt = '', ),
                response_schema = openai_connector.models.response_schema_payload.ResponseSchemaPayload(
                    properties = {
                        'key' : { }
                        }, 
                    name = '', ),
                skip_moderation = True
            )
        else:
            return PromptBundle(
                system_prompt = '',
                user_prompt = '',
        )
        """

    def testPromptBundle(self):
        """Test PromptBundle"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from openai_connector.models.chat_history_chat_content import ChatHistoryChatContent
from openai_connector.models.chat_history_item import ChatHistoryItem
from openai_connector.models.chat_role import ChatRole
from openai_connector.models.embeddings_request import EmbeddingsRequest
from openai_connector.models.embeddings_response import EmbeddingsResponse
from openai_connector.models.file_payload import FilePayload
from openai_connector.models.http_validation_error import HTTPValidationError
from openai_connector.models.image_response import ImageResponse
from openai_connector.models.image_settings import ImageSettings
from openai_connector.models.input_tokens_details import InputTokensDetails
from openai_connector.models.location_inner import LocationInner
from openai_connector.models.output_tokens_details import OutputTokensDetails
from openai_connector.models.prompt_bundle import PromptBundle
from openai_connector.models.prompt_bundle_for_generate_image import PromptBundleForGenerateImage
from openai_connector.models.response_chunk import ResponseChunk
from openai_connector.models.response_chunk_type import ResponseChunkType
from openai_connector.models.response_schema_payload import ResponseSchemaPayload
from openai_connector.models.response_usage import ResponseUsage
from openai_connector.models.text_response import TextResponse
from openai_connector.models.usage import Usage
from openai_connector.models.usage_details import UsageDetails
from openai_connector.models.usage_input_tokens_details import UsageInputTokensDetails
from openai_connector.models.validation_error import ValidationError
from openai_connector.models.wrapped_response_embeddings_response import WrappedResponseEmbeddingsResponse
from openai_connector.models.wrapped_response_image_response import WrappedResponseImageResponse
from openai_connector.models.wrapped_response_text_response import WrappedResponseTextResponse



# coding: utf-8

"""
    OpenAI Connector server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr, conlist
from openai_connector.models.chat_history_item import ChatHistoryItem
from openai_connector.models.file_payload import FilePayload
from openai_connector.models.response_schema_payload import ResponseSchemaPayload

class PromptBundle(BaseModel):
    """
    PromptBundle
    """
    model: Optional[StrictStr] = None
    system_prompt: StrictStr = Field(...)
    history: Optional[conlist(ChatHistoryItem)] = None
    user_prompt: StrictStr = Field(...)
    file: Optional[FilePayload] = None
    response_schema: Optional[ResponseSchemaPayload] = None
    skip_moderation: Optional[StrictBool] = False
    __properties = ["model", "system_prompt", "history", "user_prompt", "file", "response_schema", "skip_moderation"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> PromptBundle:
        """Create an instance of PromptBundle from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in history (list)
        _items = []
        if self.history:
            for _item in self.history:
                if _item:
                    _items.append(_item.to_dict())
            _dict['history'] = _items
        # override the default output from pydantic by calling `to_dict()` of file
        if self.file:
            _dict['file'] = self.file.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response_schema
        if self.response_schema:
            _dict['response_schema'] = self.response_schema.to_dict()
        # set to None if model (nullable) is None
        # and __fields_set__ contains the field
        if self.model is None and "model" in self.__fields_set__:
            _dict['model'] = None

        # set to None if history (nullable) is None
        # and __fields_set__ contains the field
        if self.history is None and "history" in self.__fields_set__:
            _dict['history'] = None

        # set to None if file (nullable) is None
        # and __fields_set__ contains the field
        if self.file is None and "file" in self.__fields_set__:
            _dict['file'] = None

        # set to None if response_schema (nullable) is None
        # and __fields_set__ contains the field
        if self.response_schema is None and "response_schema" in self.__fields_set__:
            _dict['response_schema'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> PromptBundle:
        """Create an instance of PromptBundle from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return PromptBundle.parse_obj(obj)

        _obj = PromptBundle.parse_obj({
            "model": obj.get("model"),
            "system_prompt": obj.get("system_prompt"),
            "history": [ChatHistoryItem.from_dict(_item) for _item in obj.get("history")] if obj.get("history") is not None else None,
            "user_prompt": obj.get("user_prompt"),
            "file": FilePayload.from_dict(obj.get("file")) if obj.get("file") is not None else None,
            "response_schema": ResponseSchemaPayload.from_dict(obj.get("response_schema")) if obj.get("response_schema") is not None else None,
            "skip_moderation": obj.get("skip_moderation") if obj.get("skip_moderation") is not None else False
        })
        return _obj


